@@ -85,10 +85,10 @@ UNAVAILABLE_RESPONSES = ('421',)
 # Random responses
 RANDOM_RESPONSES = ACCEPT_RESPONSES + BOUNCE_RESPONSES
 
-EHLO_RESPONSES = ("250-OK", "250-SIZE 512000",
+EHLO_RESPONSES = ["250-OK", "250-SIZE {0}",
                   "250-VRFY", "250-STARTTLS",
                   "250-ENHANCEDSTATUSCODES", "250-8BITMIME",
-                  "250 DSN")
+                  "250 DSN"]
 
 
 def response(response=None):
