@@ -20,16 +20,24 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
-"""blackhole.opts - command line options for the blackhole
+"""
+blackhole.opts - command line options for the blackhole
 server.
 
 Also creates a list of available ports for the server to be
 run on, based on configuration and responds with the help
-menu when requested or invalid options are given."""
-from tornado.options import define, options
+menu when requested or invalid options are given.
+"""
+
+try:
+    import ssl
+except ImportError:
+    ssl = None
+
+from tornado.options import (define, options)
 from tornado import process
 
-from blackhole import __pname__, __fullname__
+from blackhole import __pname__
 
 define('host', default="0.0.0.0", metavar="IP", type=str,
        help="IP address to bind go",
@@ -52,9 +60,14 @@ define("group", default="blackhole",
 define("log", default="/tmp/blackhole.log",
        metavar="FILE", help="File to write logs to (not very verbose)",
        group="Blackhole")
+define("message_size_limit", default=512000, metavar="BYTES", type=int,
+       help="""Maximum size of a message in Bytes, returned in EHLO but"""
+            """\n%-37snot enforced""" % "",
+       group="Blackhole")
 
 define('workers', default=None, metavar="NUM", type=int,
-       help="Number of worker processes to spawn. (default: # of CPUs/Cores - 2 + 1 master)",
+       help="""Number of worker processes to spawn."""
+            """(default: # of CPUs/Cores - 2 + 1 master)""",
        group="Workers")
 
 define('debug', default=False, metavar="BOOL", type=bool,
@@ -66,7 +79,8 @@ define('delay', default=0, metavar="INT", type=int,
        group="Delay")
 
 define("mode", default="accept",
-       metavar="MODE", help="Mode to run blackhole in (accept, bounce, random,\n%-37sunavailable, offline)" % "",
+       metavar="MODE", help="""Mode to run blackhole in (accept, bounce, """
+                            """random,\n%-37sunavailable, offline)""" % "",
        group="Mode")
 
 define('ssl', default=True, metavar="BOOL", type=bool,
@@ -86,10 +100,8 @@ define('ssl_ca_certs_dir', default=None, metavar="PATH", type=str,
        group="Blackhole SSL")
 
 # Eugh, had to replicate to shut up Tornado..
-define('version', default=True,
-       help="Return program version")
-define('v', default=True,
-       help="Return program version")
+define('version', help="Return program version")
+define('v', help="Return program version")
 
 
 def ports():
@@ -100,20 +112,24 @@ def ports():
     (std) and SSL (ssl) it is enabled.
     """
     socks_list = ['std']
-    if options.ssl:
+    # We shouldn't be able to create an SSL socket if it's
+    # disabled or if there's non SSL libary
+    if options.ssl and ssl:
         socks_list.append('ssl')
     return socks_list
 
+
 def workers():
     if options.workers is None:
         return process.cpu_count() - 2
     return options.workers
 
+
 def deprecated_opts():
     dep = ('ssl_ca_certs_dir', )
     for d in dep:
         if getattr(options, d) is not None:
-           print("Deprecated option: %s" % d)
+            print("Deprecated option: %s" % d)
 
 
 def print_help():
@@ -129,7 +145,8 @@ def print_help():
         if option.startswith(("workers", "host", "port", "pid",
                               "conf", "user", "group", "log",
                               "debug", "delay", "mode", "ssl",
-                              "ssl_port", "ssl_cert", "ssl_key")):
+                              "ssl_port", "ssl_cert", "ssl_key",
+                              "message_size_limit")):
             if not option.startswith(("log_", "logging", "ssl_ca_certs_dir")):
                 opts[option] = value
     for option in opts.values():
@@ -152,9 +169,16 @@ def print_help():
             print("  --%-30s %s" % (prefix, option.help or ""))
             if option.name == "mode":
                 print("")
-                print("%-34s accept - accept all email with code 250, 251, 252 or 253" % "")
-                print("%-34s bounce - bounce all email with a random code,\n%-37sexcluding 250, 251, 252, 253" % ("", ""))
-                print("%-34s random - randomly accept or bounce all email with a random code" % "")
-                print("%-34s unavailable - server always respondes with code 421\n%-37s- service is unavailable" % ("", ""))
-                print("%-34s offline - server always responds with code 521 - server\n%-37sdoes not accept mail" % ("", ""))
+                print("""%-34s accept - accept all email with code 250, 251,"""
+                      """ 252 or 253""" % "")
+                print("""%-34s bounce - bounce all email with a random code,"""
+                      """\n%-37sexcluding 250, 251, 252, 253""" % ("", ""))
+                print("""%-34s random - randomly accept or bounce all email"""
+                      """ with a random code""" % "")
+                print("""%-34s unavailable - server always respondes with"""
+                      """ code 421\n%-37s- service is unavailable""" %
+                      ("", ""))
+                print("""%-34s offline - server always responds with code"""
+                      """ 521 - server\n%-37sdoes not accept mail""" %
+                      ("", ""))
     print("")
