@@ -20,9 +20,11 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
-"""blackhole.utils - A utility module used for
+"""
+blackhole.utils - A utility module used for
 methods and features that do not belong in
-their own module."""
+their own module.
+"""
 
 import os
 import sys
@@ -32,8 +34,8 @@ import random
 import signal
 import socket
 
-from tornado.options import options
 import setproctitle
+from tornado.options import options
 
 from blackhole.log import log
 
@@ -107,7 +109,7 @@ def set_process_title():
     worker.
     """
     if os.path.exists(options.pid):
-        pid = int(file(options.pid, 'r').read().strip())
+        pid = int(open(options.pid, 'r').read().strip())
         if pid == os.getpid():
             setproctitle.setproctitle("blackhole: master")
         else:
@@ -135,7 +137,7 @@ def get_mailname():
     """
     mailname_file = "/etc/mailname"
     if os.path.exists(mailname_file):
-        mnc = file(mailname_file, 'r').read().strip()
+        mnc = open(mailname_file, 'r').read().strip()
         if mnc != "":
             return mnc
     return socket.getfqdn()
